street2

# XMLRésuméLibrary: User Guide

street | Element Reference | subject

## Name

street2 — A second line of a street address

Deprecated

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.3.3. It should not be used.

Because multiple `street` elements are now allowed, `street2` is unneeded. `street2` is still supported in this release of the XML Résumé Library, but may be removed in future versions. It is recommended that all `street2` elements be converted to `street` elements.

The `street2` element is similar in semantics to the `street` element. It often contains more specialized routing information than `street`, such as a suite or apartment number.

### Parents

`street2` may be contained in these elements: `address`

### Attributes

`id`

  A string used to uniquely identify the second line of a street address. The line may then be referred to by this identifier.

## See Also

`street`.

## Examples

None.

street | Element Reference | subject